set longitudes;
param pedidos{longitudes} >= 0;
param num_patrones integer >= 0;

# Con la notación 1..num_patrones en la sección del modelo, directamente se
# “puebla” el conjunto patrones con 1, 2, ..., num_patrones, es decir con
# los números naturales desde 1 hasta un valor especificado en num_patrones.
# El valor de num_patrones se especifica en la sección de los datos.
set patrones := 1..num_patrones;

param num_rollos{longitudes,patrones} >= 0;

var cortar{patrones} >= 0;

minimize Bovinas: sum{j in patrones} cortar[j];

subject to Pedido{i in longitudes}: 
    sum{j in patrones} num_rollos[i,j] * cortar[j] >= pedidos[i];

data;

# Nótese que en la sección de los datos no hay instrucciones para “poblar”
# el conjunto patrones porque eso ya se hizo en la sección del modelo. Sólo
# se especifica el número total de patrones que se usarán. 
param num_patrones := 4;

# Con esta sintáxis se "puebla" el conjunto longitudes con 20, 45, ..., 75 y
# simultáneamente se establecen los correspondientes valores del parámetro
# pedidos (i.e. 48, 35, ..., 8), el cual se indizó con el conjunto longitudes 
# en la declaración.
param:    longitudes:    pedidos := 
          20             48
          45             35
          50             24
          55             10
          75             8       ; 

param num_rollos:
          1    2    3    4 :=
    20    1    0    0    1
    45    2    0    0    0
    50    0    2    0    0
    55    0    0    2    0
    75    0    0    0    1 ;
